@@ -1,14 +1,16 @@
 import gtk
 import hildon
 import osmgpsmap
+import gobject
+import os
 
 
 class DetailsWindow(hildon.Dialog):
 
     def __init__(self, osmMapa, point, config):
         hildon.Dialog.__init__(self)
-        
-        
+
+
         self.point = point
         self.osmMapa = osmMapa
         self.CONFIG = config
@@ -18,35 +20,69 @@ class DetailsWindow(hildon.Dialog):
         self.set_default_size(500, 500)
         self.set_title("Details")
 
-
+        print "----[ details for ]-----------\n",point,"\n--------------------------"
 
 
         vbox = gtk.VBox()
         vbox0 = gtk.VBox()
 
-        vbox.pack_start( self.get_label("<big>%s</big>" % point[3]) , False)
 
 
-        osm = osmgpsmap.GpsMap()
-        osm.set_center_and_zoom( point[0], point[1], 16 )
-        osm.set_size_request(640, 160)
-        osm.image_add( point[0], point[1], point[4]  )
-        osm.connect('button_release_event', self.on_map_clicked, point[0], point[1])
-        osm.connect('button_press_event', self.on_map_clicked, point[0], point[1])
-        vbox.pack_start( osm, False)
+        lrbox = gtk.HBox()
+        tlldbox = gtk.VBox()
+
+        tlldbox.pack_start( self.get_label("<big>%s</big>" % point[3]) , False)
+
 
 
         label = gtk.Label( "Lat: %f" % point[0] )
-        vbox.pack_start( self.get_label(
+        tlldbox.pack_start( self.get_label(
             "<small>%s</small>" %  self.osmMapa.distance_to_string( self.osmMapa.distance( point[0], point[1]) )
             )
             , False)
-        vbox.pack_start( self.get_label("Latitude: %f" % point[0]), False)
-        vbox.pack_start( self.get_label("Longitude: %f" % point[1]), False)
-        vbox.pack_start( self.get_label("Point from : %s" % point[2]), False)
+
+        if len( point) == 8:
+            d = point [7]
+            try:
+                tlldbox.pack_start( self.get_label("<small>%s</small>" % d['desc']), False)
+            except:
+                pass
+
+            try:
+                if d['reference']:
+                    for plugin in self.osmMapa.plugins_list:
+                        if plugin[1] == "Google - places":
+                            ref_downloader = plugin[0]
+                            ref_downloader.get_reference( d['reference'] )
+                            self.ref_downloader_loop(ref_downloader, tlldbox)
+                            break
+            except:
+                pass
+
+        tlldbox.pack_start( self.get_label("Latitude: <small>%f</small>" % point[0]), False)
+        tlldbox.pack_start( self.get_label("Longitude: <small>%f</small>" % point[1]), False)
+        tlldbox.pack_start( self.get_label("Point from : <small>%s</small>" % point[2]), False)
 
 
 
+        if point[2] == "Google - places":
+            powerBy = gtk.Image()
+            powerBy.set_from_file("./plugins/powered-by-google-on-black.png")
+            tlldbox.pack_start( powerBy, False)
+
+
+        lrbox.pack_start( tlldbox, True)
+
+        osm = osmgpsmap.GpsMap()
+        osm.set_center_and_zoom( point[0], point[1], 16 )
+        osm.set_size_request(240, 240)
+        osm.image_add( point[0], point[1], point[4]  )
+        osm.connect('button_release_event', self.on_map_clicked, point[0], point[1])
+        osm.connect('button_press_event', self.on_map_clicked, point[0], point[1])
+        lrbox.pack_start( osm, True)
+
+        vbox.pack_start(lrbox, False)
+
         panel = hildon.PannableArea()
         panel.add_with_viewport(vbox)
         panel.set_size_request(640, 640)
@@ -59,10 +95,10 @@ class DetailsWindow(hildon.Dialog):
                            hildon.BUTTON_ARRANGEMENT_VERTICAL,"Mapa")
         bt_mapa.connect("clicked", self.on_mapa)
         bt_hbox.pack_start( bt_mapa, True)
-        
-        
-        
-        
+
+
+
+
         if self.CONFIG['POI']:
             bt_poi = hildon.Button(gtk.HILDON_SIZE_AUTO_WIDTH | gtk.HILDON_SIZE_FINGER_HEIGHT,
                            hildon.BUTTON_ARRANGEMENT_VERTICAL,"POI")
@@ -76,18 +112,43 @@ class DetailsWindow(hildon.Dialog):
             bt_hbox.pack_start( bt_route, True)
 
 
-        vbox0.pack_start(bt_hbox,False)
-        
+        vbox.pack_start(bt_hbox,False)
+
 
         self.vbox.pack_start(vbox0, True)
 
         self.show_all()
-        
-        
-        
+
+
+
         self.run()
         self.destroy()
 
+    def ref_downloader_loop(self, ref_downloader, tlldbox):
+        if ref_downloader.ref_result == []:
+            gobject.timeout_add( 1000, self.ref_downloader_loop, ref_downloader, tlldbox )
+        else:
+            try:
+                tlldbox.pack_start( self.get_label("Addres: <small>%s</small>" % ref_downloader.ref_result[1]), False)
+
+                hbox = gtk.HBox()
+                l = gtk.Label("Phone: ")
+                hbox.pack_start(l, False)
+
+                bt_phone = hildon.Button(gtk.HILDON_SIZE_AUTO_WIDTH | gtk.HILDON_SIZE_FINGER_HEIGHT,
+                           hildon.BUTTON_ARRANGEMENT_VERTICAL,"%s" % ref_downloader.ref_result[2])
+                bt_phone.connect("clicked",self.on_call_clicked, ref_downloader.ref_result[2] )
+                hbox.pack_start( bt_phone, True)
+
+                tlldbox.pack_start( hbox, False)
+
+                tlldbox.show_all()
+            except Exception, e:
+                print "add reference error",e
+
+    def on_call_clicked(self,w,tel):
+        os.system("dbus-send --system --dest=com.nokia.csd.Call --type=method_call --print-reply /com/nokia/csd/call com.nokia.csd.Call.CreateWith string:\"%s\" uint32:0 &" % tel )
+
     def on_route_to_it(self, w, lat, lon):
         p = None
         for plugin in self.osmMapa.plugins_list:
@@ -100,7 +161,7 @@ class DetailsWindow(hildon.Dialog):
             self.CONFIG['google_routesearch_to'] = "loc:%f+%f" %( lat, lon)
             p.search_action()
             self.destroy()
-            
+
     def on_add_as_poi(self, w, lat, lon):
         poi = None
         for plugin in self.osmMapa.plugins_list:
@@ -122,6 +183,7 @@ class DetailsWindow(hildon.Dialog):
     def get_label(self, str):
         hbox = gtk.HBox( spacing = 5 )
         l0 = gtk.Label()
+        l0.set_line_wrap( True )
         l0.set_markup( str )
         hbox.pack_start( l0, False)
 
