@@ -20,9 +20,9 @@ class nominatimDownloader(Thread):
         self.zoom_start = self.geonames.osmMapa.osm.props.zoom
         self.str = str
         self.more = more
-        
+
         self.zoom_out_iter = 0
-        
+
     def parseXml(self, xml_res):
         doc = xml.dom.minidom.parseString(xml_res)
         tr = []
@@ -30,7 +30,8 @@ class nominatimDownloader(Thread):
             for p in doc.getElementsByTagName("place"):
                 lat = float(p.getAttribute("lat"))
                 lon = float(p.getAttribute("lon"))
-                name = p.getAttribute("display_name").split(",")[0]
+                desc = p.getAttribute("display_name")
+                name = desc.split(",")[0]
 
                 try:
                     ico_href = p.getAttribute("icon")
@@ -59,7 +60,10 @@ class nominatimDownloader(Thread):
                         name,
                         ico,
                         None,
-                        self.geonames.from_zoom
+                        self.geonames.from_zoom,
+                        {
+                            'desc': desc
+                         }
                         ])
 
         except Exception, e:
@@ -93,7 +97,7 @@ class nominatimDownloader(Thread):
         print "nominatimDownloader parse DONE len(",len(tr),")"
 
         if len(tr)==0 and self.zoom_out_iter < 5:
-            
+
             dis = self.geonames.osmMapa.cal_dist( self.box[0], self.box[1], self.box[2], self.box[3] )
             if dis<0: dis = -dis
             self.box = [
@@ -102,7 +106,7 @@ class nominatimDownloader(Thread):
                         self.box[2]+dis,
                         self.box[3]+dis
                         ]
-            self.zoom_out_iter+=1            
+            self.zoom_out_iter+=1
             #self.geonames.osmMapa.showBanner("looking on bigger area")
             self.run()
         elif len(tr)==0:
@@ -113,7 +117,7 @@ class nominatimDownloader(Thread):
             #self.geonames.osmMapa.osm.set_zoom( self.zoom_start )
             print "nominatimDownloader downolad"
             print "nominatimDownloader DONE"
-        
+
         if len( tr ) > 0:
             for p in tr:
                 self.geonames.osmMapa.show_find_results.append( p )
@@ -144,7 +148,7 @@ class nominatim_geonames:
         self.timeout = 3
         self.downloadMore = 0
 
-        
+
 
         try:
             print "nominatim_geonames recent search for:\n",self.CONFIG['nominatim_geonames_recent_search'],"\n-----------"
@@ -164,7 +168,7 @@ class nominatim_geonames:
 
         print "__init__ nominatim_geonames"
 
-        
+
 
     def killIt(self):
         self.osmMapa.marker_layer_clean( self.get_name() )
@@ -172,8 +176,8 @@ class nominatim_geonames:
     def makeInit(self):
         pass
 
-    
-    
+
+
     def get_name(self):
         return "Nominatim - geonames"
 
@@ -186,7 +190,7 @@ class nominatim_geonames:
         t = nominatimDownloader( self, self.box, self.CONFIG['nominatim_geonames_search'])
         t.start()
         return []
-    
+
     def get_menu_widgets(self, dialog):
         return None
 
