@@ -336,43 +336,43 @@ class YosmapaOSD(gobject.GObject, osmgpsmap.GpsMapLayer):
                     else:
                         cr = self.gdkdrawable.cairo_create()
                         self.osmMapa.draw_cloud_byll(cr, c[4])
-                    
+
 
 
             for c in self.osmMapa.clikable_clouds:
                 if x >= c[0] and y >= c[1] and x<= c[2] and y<= c[3]:
-                    
+
                     if type(c[6]) == list:
                         self.on_details(None,c[6])
-                    
+
                     """
                     else:
                         m = gtk.Menu()
                         latc,lonc = self.osmMapa.get_may_current_ll()
                         dis = self.osmMapa.distance_to_string( self.osmMapa.distance( latc, lonc, c[4], c[5]) )
-    
+
                         mi = gtk.MenuItem("___________Distans it: %s" % dis)
                         m.append(mi)
-    
+
                         mi = gtk.MenuItem("___________Center to")
                         mi.connect("activate",self.on_set_center,c[4],c[5])
                         m.append(mi)
-    
+
                         if CONFIG['POI']:
                             mi = gtk.MenuItem("___________Add as POI")
                             mi.connect("activate",self.on_add_as_poi,c[4],c[5])
                             m.append(mi)
-    
+
                         if CONFIG['Google - routesearch']:
                             mi = gtk.MenuItem("___________Route to it")
                             mi.connect("activate",self.on_route_to_it,c[4],c[5])
                             m.append(mi)
-                            
+
                         if type(c[6]) == list:
                             mi = gtk.MenuItem("___________Details")
                             mi.connect("activate",self.on_details,c[6])
                             m.append(mi)
-    
+
                         m.show_all()
                         m.popup( None, None, None , 2, 0)
                     """
@@ -383,7 +383,7 @@ class YosmapaOSD(gobject.GObject, osmgpsmap.GpsMapLayer):
 
     def on_details(self, w, point):
         w = DetailsWindow( self.osmMapa, point, CONFIG )
-        
+
     """
     def on_route_to_it(self, w, lat, lon):
         p = None
@@ -665,13 +665,14 @@ class UI(gtk.Window):
         else:
             make_from = self.markers
 
+
         self.clikable_icons = []
         if len(self.cliked_item) == 2:
             icon_clicked = 1
             #print "icon_clicked !",self.cliked_item
         else:
             icon_clicked = 0
-            
+
         for m in make_from:
             lt = m[0]
             ln = m[1]
@@ -684,6 +685,13 @@ class UI(gtk.Window):
 
                 if not m[5]:
                     m[5] = self.osm.image_add( lt, ln, m[4] )
+                    if self.cliked_item == [] and m[3]:
+                        self.cliked_item = [lt,ln]
+                        icon_clicked = 1
+                else:
+                    if self.cliked_item == [] and m[3]:
+                        self.cliked_item = [lt,ln]
+                        icon_clicked = 1
 
 
                 if m[2] == "Google - routesearch" and m[3]:
@@ -695,7 +703,10 @@ class UI(gtk.Window):
                 if m[5]:
                     self.osm.image_remove(m[5])
                     m[5] = None
-        
+                    if icon_clicked:
+                        if self.cliked_item[0] == m[0] and self.cliked_item[1] == m[1]:
+                            self.cliked_item = []
+
 
     def marker_clear_from_layer(self, from_what):
         for m in from_what:
@@ -840,7 +851,7 @@ class UI(gtk.Window):
         if type(str) == list:
             point = str
             str = point[3]
-            
+
         if str == "" or str == None:
             return None
         if x<0:
